aboutsummaryrefslogtreecommitdiffstats
path: root/mail/e-mail-sidebar.c
diff options
context:
space:
mode:
authorMatthew Barnes <mbarnes@redhat.com>2013-02-01 05:14:49 +0800
committerMatthew Barnes <mbarnes@redhat.com>2013-02-01 06:39:05 +0800
commitfd43cd692ad12e7f9c70386c1b0867b16f9ec15d (patch)
tree7de35780745b82c9655e0bbc87945f36368c4643 /mail/e-mail-sidebar.c
parentfc3bf6f39e7215df6325515afff3217aedb2cc10 (diff)
downloadgsoc2013-evolution-fd43cd692ad12e7f9c70386c1b0867b16f9ec15d.tar
gsoc2013-evolution-fd43cd692ad12e7f9c70386c1b0867b16f9ec15d.tar.gz
gsoc2013-evolution-fd43cd692ad12e7f9c70386c1b0867b16f9ec15d.tar.bz2
gsoc2013-evolution-fd43cd692ad12e7f9c70386c1b0867b16f9ec15d.tar.lz
gsoc2013-evolution-fd43cd692ad12e7f9c70386c1b0867b16f9ec15d.tar.xz
gsoc2013-evolution-fd43cd692ad12e7f9c70386c1b0867b16f9ec15d.tar.zst
gsoc2013-evolution-fd43cd692ad12e7f9c70386c1b0867b16f9ec15d.zip
Incorporate ESourceUOA.
Where we make exceptions for GNOME Online Accounts, so too shall we for Ubuntu Online Accounts.
Diffstat (limited to 'mail/e-mail-sidebar.c')
-rw-r--r--mail/e-mail-sidebar.c9
1 files changed, 8 insertions, 1 deletions
diff --git a/mail/e-mail-sidebar.c b/mail/e-mail-sidebar.c
index aafa6cd302..20cf41404c 100644
--- a/mail/e-mail-sidebar.c
+++ b/mail/e-mail-sidebar.c
@@ -485,7 +485,7 @@ mail_sidebar_check_state (EMailSidebar *sidebar)
can_delete &= !(folder_flags & CAMEL_FOLDER_SYSTEM);
}
/* GOA-based accounts cannot be disabled from Evolution. */
if (is_store && !store_is_local && !store_is_vfolder) {
EMFolderTree *folder_tree;
EMailSession *session;
@@ -505,6 +505,13 @@ mail_sidebar_check_state (EMailSidebar *sidebar)
g_object_unref (ancestor);
}
+ ancestor = e_source_registry_find_extension (
+ registry, source, E_SOURCE_EXTENSION_UOA);
+ if (ancestor != NULL) {
+ can_disable = FALSE;
+ g_object_unref (ancestor);
+ }
+
g_object_unref (source);
}
@@ -485,7 +485,7 @@ mail_sidebar_check_state (EMailSidebar *sidebar)
can_delete &= !(folder_flags & CAMEL_FOLDER_SYSTEM);
}
- /* GOA-based accounts cannot be disabled from Evolution. */
+ /* GOA and UOA-based accounts cannot be disabled from Evolution. */
if (is_store && !store_is_local && !store_is_vfolder) {
EMFolderTree *folder_tree;